@@ -93,6 +93,23 @@ extern "C" {
  */
 #define SRTP_MAX_TRAILER_LEN (SRTP_MAX_TAG_LEN + SRTP_MAX_MKI_LEN)
 
+/**
+ * SRTP_SRCTP_INDEX_LEN is the size the SRTCP index which is
+ * 4 bytes
+ */
+#define SRTP_SRCTP_INDEX_LEN 4
+
+/**
+ * SRTP_MAX_SRTCP_TRAILER_LEN is the maximum length of the SRTCP trailer
+ * (index, authentication tag and MKI) supported by libSRTP.  This value is
+ * the maximum number of octets that will be added to an RTCP packet by
+ * srtp_protect_rtcp().
+ *
+ * @brief the maximum number of octets added by srtp_protect().
+ */
+#define SRTP_MAX_SRTCP_TRAILER_LEN                                             \
+    (SRTP_SRCTP_INDEX_LEN + SRTP_MAX_TAG_LEN + SRTP_MAX_MKI_LEN)
+
 /**
  * SRTP_MAX_NUM_MASTER_KEYS is the maximum number of Master keys for
  * MKI supported by libSRTP.
@@ -1192,7 +1209,7 @@ typedef enum {
     srtp_profile_null_sha1_80 = 5,
     srtp_profile_null_sha1_32 = 6,
     srtp_profile_aead_aes_128_gcm = 7,
-    srtp_profile_aead_aes_256_gcm = 8,
+    srtp_profile_aead_aes_256_gcm = 8
 } srtp_profile_t;
 
 /**
@@ -1314,7 +1331,7 @@ void srtp_append_salt_to_key(unsigned char *key,
  * packet, and assumes that the RTCP packet is aligned on a 32-bit
  * boundary.
  *
- * @warning This function assumes that it can write SRTP_MAX_TRAILER_LEN+4
+ * @warning This function assumes that it can write SRTP_MAX_SRTCP_TRAILER_LEN
  * into the location in memory immediately following the RTCP packet.
  * Callers MUST ensure that this much writable memory is available in
  * the buffer that holds the RTCP packet.
@@ -1355,7 +1372,7 @@ srtp_err_status_t srtp_protect_rtcp(srtp_t ctx,
  * packet, and assumes that the RTCP packet is aligned on a 32-bit
  * boundary.
  *
- * @warning This function assumes that it can write SRTP_MAX_TRAILER_LEN+4
+ * @warning This function assumes that it can write SRTP_MAX_SRTCP_TRAILER_LEN
  * into the location in memory immediately following the RTCP packet.
  * Callers MUST ensure that this much writable memory is available in
  * the buffer that holds the RTCP packet.
